@@ -45,12 +45,16 @@ class StatisticsPerStream(object):
                  live_multiplicator=None,
                  enhanced_deinterlace=None,
                  enhanced_deinterlace_multiplicator=None,
+                 dolby_vision_to_hdr=None,
+                 dolby_vision_to_hdr_multiplicator=None,
+                 dolby_vision_to_sdr=None,
+                 dolby_vision_to_sdr_multiplicator=None,
                  nex_guard_ab_watermarking_type=None,
                  nex_guard_ab_watermarking_multiplicator=None,
                  pixel_format_bit_depth=None,
                  pixel_format_multiplicator=None,
                  input_factor=None):
-        # type: (string_types, string_types, float, int, float, float, int, int, float, int, CodecConfigType, StatisticsResolution, EncodingMode, float, StatisticsPerTitleStream, float, PsnrPerStreamMode, float, DolbyVisionPerStreamMode, float, string_types, float, bool, float, bool, float, NexGuardABWatermarkingFeature, float, PixelFormatBitDepth, float, InputFactor) -> None
+        # type: (string_types, string_types, float, int, float, float, int, int, float, int, CodecConfigType, StatisticsResolution, EncodingMode, float, StatisticsPerTitleStream, float, PsnrPerStreamMode, float, DolbyVisionPerStreamMode, float, string_types, float, bool, float, bool, float, bool, float, bool, float, NexGuardABWatermarkingFeature, float, PixelFormatBitDepth, float, InputFactor) -> None
 
         self._stream_id = None
         self._codec_config_id = None
@@ -78,6 +82,10 @@ class StatisticsPerStream(object):
         self._live_multiplicator = None
         self._enhanced_deinterlace = None
         self._enhanced_deinterlace_multiplicator = None
+        self._dolby_vision_to_hdr = None
+        self._dolby_vision_to_hdr_multiplicator = None
+        self._dolby_vision_to_sdr = None
+        self._dolby_vision_to_sdr_multiplicator = None
         self._nex_guard_ab_watermarking_type = None
         self._nex_guard_ab_watermarking_multiplicator = None
         self._pixel_format_bit_depth = None
@@ -137,6 +145,14 @@ class StatisticsPerStream(object):
             self.enhanced_deinterlace = enhanced_deinterlace
         if enhanced_deinterlace_multiplicator is not None:
             self.enhanced_deinterlace_multiplicator = enhanced_deinterlace_multiplicator
+        if dolby_vision_to_hdr is not None:
+            self.dolby_vision_to_hdr = dolby_vision_to_hdr
+        if dolby_vision_to_hdr_multiplicator is not None:
+            self.dolby_vision_to_hdr_multiplicator = dolby_vision_to_hdr_multiplicator
+        if dolby_vision_to_sdr is not None:
+            self.dolby_vision_to_sdr = dolby_vision_to_sdr
+        if dolby_vision_to_sdr_multiplicator is not None:
+            self.dolby_vision_to_sdr_multiplicator = dolby_vision_to_sdr_multiplicator
         if nex_guard_ab_watermarking_type is not None:
             self.nex_guard_ab_watermarking_type = nex_guard_ab_watermarking_type
         if nex_guard_ab_watermarking_multiplicator is not None:
@@ -177,6 +193,10 @@ class StatisticsPerStream(object):
             'live_multiplicator': 'float',
             'enhanced_deinterlace': 'bool',
             'enhanced_deinterlace_multiplicator': 'float',
+            'dolby_vision_to_hdr': 'bool',
+            'dolby_vision_to_hdr_multiplicator': 'float',
+            'dolby_vision_to_sdr': 'bool',
+            'dolby_vision_to_sdr_multiplicator': 'float',
             'nex_guard_ab_watermarking_type': 'NexGuardABWatermarkingFeature',
             'nex_guard_ab_watermarking_multiplicator': 'float',
             'pixel_format_bit_depth': 'PixelFormatBitDepth',
@@ -215,6 +235,10 @@ class StatisticsPerStream(object):
             'live_multiplicator': 'liveMultiplicator',
             'enhanced_deinterlace': 'enhancedDeinterlace',
             'enhanced_deinterlace_multiplicator': 'enhancedDeinterlaceMultiplicator',
+            'dolby_vision_to_hdr': 'dolbyVisionToHdr',
+            'dolby_vision_to_hdr_multiplicator': 'dolbyVisionToHdrMultiplicator',
+            'dolby_vision_to_sdr': 'dolbyVisionToSdr',
+            'dolby_vision_to_sdr_multiplicator': 'dolbyVisionToSdrMultiplicator',
             'nex_guard_ab_watermarking_type': 'nexGuardABWatermarkingType',
             'nex_guard_ab_watermarking_multiplicator': 'nexGuardABWatermarkingMultiplicator',
             'pixel_format_bit_depth': 'pixelFormatBitDepth',
@@ -965,6 +989,122 @@ class StatisticsPerStream(object):
 
         self._enhanced_deinterlace_multiplicator = enhanced_deinterlace_multiplicator
 
+    @property
+    def dolby_vision_to_hdr(self):
+        # type: () -> bool
+        """Gets the dolby_vision_to_hdr of this StatisticsPerStream.
+
+        Indicates if the conversion from Dolby Vision to HDR was triggered.
+
+        :return: The dolby_vision_to_hdr of this StatisticsPerStream.
+        :rtype: bool
+        """
+        return self._dolby_vision_to_hdr
+
+    @dolby_vision_to_hdr.setter
+    def dolby_vision_to_hdr(self, dolby_vision_to_hdr):
+        # type: (bool) -> None
+        """Sets the dolby_vision_to_hdr of this StatisticsPerStream.
+
+        Indicates if the conversion from Dolby Vision to HDR was triggered.
+
+        :param dolby_vision_to_hdr: The dolby_vision_to_hdr of this StatisticsPerStream.
+        :type: bool
+        """
+
+        if dolby_vision_to_hdr is not None:
+            if not isinstance(dolby_vision_to_hdr, bool):
+                raise TypeError("Invalid type for `dolby_vision_to_hdr`, type has to be `bool`")
+
+        self._dolby_vision_to_hdr = dolby_vision_to_hdr
+
+    @property
+    def dolby_vision_to_hdr_multiplicator(self):
+        # type: () -> float
+        """Gets the dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.
+
+        The output minutes multiplicator for streams using the conversion from Dolby Vision to HDR.
+
+        :return: The dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.
+        :rtype: float
+        """
+        return self._dolby_vision_to_hdr_multiplicator
+
+    @dolby_vision_to_hdr_multiplicator.setter
+    def dolby_vision_to_hdr_multiplicator(self, dolby_vision_to_hdr_multiplicator):
+        # type: (float) -> None
+        """Sets the dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.
+
+        The output minutes multiplicator for streams using the conversion from Dolby Vision to HDR.
+
+        :param dolby_vision_to_hdr_multiplicator: The dolby_vision_to_hdr_multiplicator of this StatisticsPerStream.
+        :type: float
+        """
+
+        if dolby_vision_to_hdr_multiplicator is not None:
+            if not isinstance(dolby_vision_to_hdr_multiplicator, (float, int)):
+                raise TypeError("Invalid type for `dolby_vision_to_hdr_multiplicator`, type has to be `float`")
+
+        self._dolby_vision_to_hdr_multiplicator = dolby_vision_to_hdr_multiplicator
+
+    @property
+    def dolby_vision_to_sdr(self):
+        # type: () -> bool
+        """Gets the dolby_vision_to_sdr of this StatisticsPerStream.
+
+        Indicates if the conversion from Dolby Vision to SDR was triggered.
+
+        :return: The dolby_vision_to_sdr of this StatisticsPerStream.
+        :rtype: bool
+        """
+        return self._dolby_vision_to_sdr
+
+    @dolby_vision_to_sdr.setter
+    def dolby_vision_to_sdr(self, dolby_vision_to_sdr):
+        # type: (bool) -> None
+        """Sets the dolby_vision_to_sdr of this StatisticsPerStream.
+
+        Indicates if the conversion from Dolby Vision to SDR was triggered.
+
+        :param dolby_vision_to_sdr: The dolby_vision_to_sdr of this StatisticsPerStream.
+        :type: bool
+        """
+
+        if dolby_vision_to_sdr is not None:
+            if not isinstance(dolby_vision_to_sdr, bool):
+                raise TypeError("Invalid type for `dolby_vision_to_sdr`, type has to be `bool`")
+
+        self._dolby_vision_to_sdr = dolby_vision_to_sdr
+
+    @property
+    def dolby_vision_to_sdr_multiplicator(self):
+        # type: () -> float
+        """Gets the dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.
+
+        The output minutes multiplicator for streams using the conversion from Dolby Vision to SDR.
+
+        :return: The dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.
+        :rtype: float
+        """
+        return self._dolby_vision_to_sdr_multiplicator
+
+    @dolby_vision_to_sdr_multiplicator.setter
+    def dolby_vision_to_sdr_multiplicator(self, dolby_vision_to_sdr_multiplicator):
+        # type: (float) -> None
+        """Sets the dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.
+
+        The output minutes multiplicator for streams using the conversion from Dolby Vision to SDR.
+
+        :param dolby_vision_to_sdr_multiplicator: The dolby_vision_to_sdr_multiplicator of this StatisticsPerStream.
+        :type: float
+        """
+
+        if dolby_vision_to_sdr_multiplicator is not None:
+            if not isinstance(dolby_vision_to_sdr_multiplicator, (float, int)):
+                raise TypeError("Invalid type for `dolby_vision_to_sdr_multiplicator`, type has to be `float`")
+
+        self._dolby_vision_to_sdr_multiplicator = dolby_vision_to_sdr_multiplicator
+
     @property
     def nex_guard_ab_watermarking_type(self):
         # type: () -> NexGuardABWatermarkingFeature
