@@ -346,7 +346,7 @@ class Subtask(BitmovinResponse):
         # type: () -> datetime
         """Gets the running_at of this Subtask.
 
-        Timestamp when the subtask status changed to to 'RUNNING', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
+        Timestamp when the subtask status changed to 'RUNNING', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
 
         :return: The running_at of this Subtask.
         :rtype: datetime
@@ -358,7 +358,7 @@ class Subtask(BitmovinResponse):
         # type: (datetime) -> None
         """Sets the running_at of this Subtask.
 
-        Timestamp when the subtask status changed to to 'RUNNING', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
+        Timestamp when the subtask status changed to 'RUNNING', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
 
         :param running_at: The running_at of this Subtask.
         :type: datetime
@@ -375,7 +375,7 @@ class Subtask(BitmovinResponse):
         # type: () -> datetime
         """Gets the finished_at of this Subtask.
 
-        Timestamp when the subtask status changed to 'FINISHED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
+        Timestamp when the subtask status changed to a final state like  'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for subtasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 
 
         :return: The finished_at of this Subtask.
         :rtype: datetime
@@ -387,7 +387,7 @@ class Subtask(BitmovinResponse):
         # type: (datetime) -> None
         """Sets the finished_at of this Subtask.
 
-        Timestamp when the subtask status changed to 'FINISHED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
+        Timestamp when the subtask status changed to a final state like  'FINISHED', 'ERROR', 'CANCELED', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp might be inaccurate for subtasks which ran prior to the [1.50.0 REST API release](https://bitmovin.com/docs/encoding/changelogs/rest). 
 
         :param finished_at: The finished_at of this Subtask.
         :type: datetime
@@ -404,7 +404,7 @@ class Subtask(BitmovinResponse):
         # type: () -> datetime
         """Gets the error_at of this Subtask.
 
-        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
+        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 
 
         :return: The error_at of this Subtask.
         :rtype: datetime
@@ -416,7 +416,7 @@ class Subtask(BitmovinResponse):
         # type: (datetime) -> None
         """Sets the error_at of this Subtask.
 
-        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ 
+        Timestamp when the subtask status changed to 'ERROR', returned as UTC expressed in ISO 8601 format: YYYY-MM-DDThh:mm:ssZ  Note that this timestamp is deprecated and is equivalent to finishedAt in case of an 'ERROR'. 
 
         :param error_at: The error_at of this Subtask.
         :type: datetime
